==> camel-core-reifier-3.11.0-sources.jar: org/apache/camel/reifier/UnmarshalReifier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.reifier;

import org.apache.camel.Processor;
import org.apache.camel.Route;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.model.UnmarshalDefinition;
import org.apache.camel.reifier.dataformat.DataFormatReifier;
import org.apache.camel.spi.DataFormat;
import org.apache.camel.support.processor.UnmarshalProcessor;

public class UnmarshalReifier extends ProcessorReifier<UnmarshalDefinition> {

    public UnmarshalReifier(Route route, ProcessorDefinition<?> definition) {
        super(route, (UnmarshalDefinition) definition);
    }

    @Override
    public Processor createProcessor() {
        DataFormat dataFormat = DataFormatReifier.getDataFormat(camelContext, definition.getDataFormatType());
        return new UnmarshalProcessor(dataFormat);
    }
}

==> camel-core-reifier-4.0.4-sources.jar: org/apache/camel/reifier/UnmarshalReifier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.reifier;

import org.apache.camel.Processor;
import org.apache.camel.Route;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.model.UnmarshalDefinition;
import org.apache.camel.reifier.dataformat.DataFormatReifier;
import org.apache.camel.spi.DataFormat;
import org.apache.camel.support.processor.UnmarshalProcessor;

public class UnmarshalReifier extends ProcessorReifier<UnmarshalDefinition> {

    public UnmarshalReifier(Route route, ProcessorDefinition<?> definition) {
        super(route, (UnmarshalDefinition) definition);
    }

    @Override
    public Processor createProcessor() {
        DataFormat dataFormat = DataFormatReifier.getDataFormat(camelContext, definition.getDataFormatType());
        return new UnmarshalProcessor(dataFormat, Boolean.TRUE == parseBoolean(definition.getAllowNullBody()));
    }
}
